<?php

declare(strict_types=1);

namespace Drupal\iubenda_integration;

/**
 * Interface for parsing embed codes.
 */
interface EmbedCodeParserInterface {

  /**
   * Extracts the JSON configuration from an embed code snippet.
   *
   * This method uses a regular expression to find and extract the JSON
   * configuration assigned to `_iub.csConfiguration` within the provided
   * cookie solution embed code snippet.
   *
   * @param string $snippet
   *   The embed code snippet containing the configuration.
   *
   * @return array
   *   The extracted JSON configuration as an array.
   *
   * @throws \Drupal\iubenda_integration\Exception\InvalidEmbedCodeException
   *   If the embed code does not contain a valid configuration.
   */
  public function decodeCookieSolutionConfig(string $snippet): array;

  /**
   * Extracts the JSON language configuration from an embed code snippet.
   *
   * This method uses a regular expression to find and extract the JSON
   * configuration assigned to `_iub.csLangConfiguration` within the provided
   * cookie solution embed code snippet.
   *
   * @param string $snippet
   *   The embed code snippet containing the language configuration.
   *
   * @return array
   *   The extracted JSON language configuration as an array. If only one
   *   language is configured, it returns an empty array.
   *
   * @throws \Drupal\iubenda_integration\Exception\InvalidEmbedCodeException
   *   If the embed code does not contain a valid language configuration.
   */
  public function decodeCookieSolutionLangConfig(string $snippet): array;

}
