<?php

declare(strict_types=1);

namespace Drupal\iubenda_integration\Enum;

/**
 * Enum for the iubenda blocks.
 *
 * This enum represents the different iubenda blocks that can be displayed in
 * the iubenda integration module. This list is useful to instantiate the
 * different derived block plugins.
 *
 * @see \Drupal\iubenda_integration\Plugin\Block\IubendaBlock
 * @see \Drupal\iubenda_integration\Plugin\Derivative\IubendaBlockDeriver
 * @see \Drupal\iubenda_integration\IubendaRenderer
 */
enum IubendaBlocks: string {

  case IubendaPrivacyPolicy = 'Privacy policy';

  case IubendaCookiePolicy = 'Cookie policy';

  case IubendaTermsAndCondition = 'Terms and condition';

  /**
   * Returns the enum case from the name.
   *
   * @param string $name
   *   The name of the enum case.
   *
   * @return static|null
   *   The enum case or NULL if not found.
   */
  public static function tryFromName(string $name): ?static {
    $result = array_filter(self::cases(), fn ($item) => $item->name === $name);
    if (empty($result)) {
      return NULL;
    }

    return reset($result);
  }

}
