<?php

namespace Drupal\iubenda_integration\Form;

use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures iubenda_integration settings.
 */
class ConsentDatabaseConfigForm extends IubendaConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'iubenda_integration_settings_consent';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config(self::CONFIG_NAME);

    $form['intro'] = [
      '#type' => 'item',
      '#markup' => $this->t('<b>First</b>, go to your @dashboard_link and click on
        <em>[Your website] > Consent Database > Edit</em> to activate & configure your Consent Database.
        <b>Then</b>, paste here your public API key.', [
          '@dashboard_link' => $this->getDashboardLink()->toString(),
        ],
      ),
    ];

    $form['consent_solution_api_key'] = [
      '#type' => 'key_select',
      '#title' => $this->t('Api key'),
      '#description' => $this->t('Where can I @cs_doc it?', [
        '@cs_doc' => $this->getConsentSolutionDocLink()->toString(),
      ]),
      '#required' => TRUE,
      '#default_value' => $config->get('consent_solution_api_key'),
      '#key_filters' => ['type' => 'iubenda_consent_database_api'],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config(self::CONFIG_NAME)
      ->set('consent_solution_api_key', $form_state->getValue('consent_solution_api_key'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
