<?php

declare(strict_types=1);

namespace Drupal\iubenda_integration\Form;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Cache\CacheTagsInvalidatorInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\iubenda_integration\Traits\IubendaLinkTrait;
use Drupal\iubenda_integration\Traits\IubendaSettingsTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a base class for iubenda configuration forms.
 */
abstract class IubendaConfigFormBase extends ConfigFormBase {

  use IubendaLinkTrait, IubendaSettingsTrait;

  /**
   * The cache tags invalidator service.
   */
  private CacheTagsInvalidatorInterface $cacheTagsInvalidator;

  /**
   * The cache discovery service.
   */
  private CacheBackendInterface $cacheBackendDiscovery;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    $instance = parent::create($container);

    $cache_tags_invalidator = $container->get('cache_tags.invalidator');
    assert($cache_tags_invalidator instanceof CacheTagsInvalidatorInterface);
    $instance->cacheTagsInvalidator = $cache_tags_invalidator;

    $cache_discovery = $container->get('cache.discovery');
    assert($cache_discovery instanceof CacheBackendInterface);
    $instance->cacheBackendDiscovery = $cache_discovery;

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [self::CONFIG_NAME];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['#attached'] = [
      'library' => [
        'iubenda_integration/config-form',
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);
    $this->cacheTagsInvalidator->invalidateTags(['iubenda_integration.settings', 'block_plugins']);
    // For a more thorough regeneration of all plugin definitions,
    // including derived ones, clear the entire 'discovery' cache bin.
    // This is a broader approach than just invalidating 'block_plugins'.
    $this->cacheBackendDiscovery->deleteAll();
  }

}
