<?php

declare(strict_types=1);

namespace Drupal\iubenda_integration\Form;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a form for configuring the iubenda Terms and Condition settings.
 */
final class TermsAndConditionConfigForm extends IubendaConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'iubenda_integration_terms_and_condition';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config(self::CONFIG_NAME);

    $form['intro'] = [
      '#type' => 'item',
      '#markup' => $this->t('<b>First</b>, go to your @dashboard_link and click on
        <em>[Your website] > Terms and Conditions > Edit</em> to configure your conditions.
        <b>Then</b>, paste here the generated Terms and Conditions URL.
        <b>Finally</b>, place the @blocks wherever you want to display the Terms and Conditions on your site.', [
          '@dashboard_link' => $this->getDashboardLink()->toString(),
          '@blocks' => $this->getBlockLayoutLink('Iubenda: Terms and conditions')->toString(),
        ],
      ),
    ];

    $form['terms_and_condition_url'] = [
      '#type' => 'url',
      '#title' => $this->t('Term and Condition URL'),
      '#size' => 60,
      '#pattern' => 'https://www.iubenda.com/terms-and-conditions/[0-9]+',
      '#description' => $this->t('Insert the Term and Condition URL from your Iubenda dashboard (e.g. https://www.iubenda.com/terms-and-conditions/12345678).'),
      '#default_value' => $config->get('terms_and_condition_url'),
      '#placeholder' => 'https://www.iubenda.com/terms-and-conditions/12345678',
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config(self::CONFIG_NAME)
      ->set('terms_and_condition_url', $form_state->getValue('terms_and_condition_url'))
      ->save();
    Cache::invalidateTags(['iubenda_integration.settings']);
    parent::submitForm($form, $form_state);
  }

}
