<?php

declare(strict_types=1);

namespace Drupal\iubenda_integration;

use Drupal\Core\GeneratedLink;
use Drupal\iubenda_integration\Enum\IubendaBlocks;

/**
 * This class contains methods to manage the privacy policy rendering.
 *
 * @group iubenda_integration
 */
interface IubendaRendererInterface {

  /**
   * Builds the Iubenda policy link.
   *
   * @param \Drupal\iubenda_integration\Enum\IubendaBlocks $policy
   *   The Iubenda policy to link to.
   * @param string $link_text
   *   The link text.
   *
   * @return \Drupal\Core\GeneratedLink
   *   Iubenda policy link as HTML markup.
   *
   * @throws \InvalidArgumentException
   */
  public function buildLink(IubendaBlocks $policy, string $link_text = ''): GeneratedLink;

  /**
   * Build the Iubenda policy text.
   *
   * @param \Drupal\iubenda_integration\Enum\IubendaBlocks $policy
   *   The Iubenda policy to build the string for.
   *
   * @return string
   *   A string containing the configured Iubenda pre-text, link and post-text.
   */
  public function buildString(IubendaBlocks $policy): string;

  /**
   * Builds the iubenda privacy policy form validation element.
   *
   * This method is used to create a form element that validates the user's
   * acceptance of the Iubenda privacy policy before form submission.
   * It typically includes a checkbox or similar input that the user must check
   * to indicate their agreement to the privacy policy terms.
   *
   * @param array $form
   *   The form array to which the validation element will be added.
   * @param string $form_id
   *   The ID of the form being built, used to identify the specific form
   *   for which the validation element is being created.
   */
  public function buildFormValidationElement(array &$form, string $form_id): void;

}
