<?php

declare(strict_types=1);

namespace Drupal\iubenda_integration\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\iubenda_integration\Enum\IubendaBlocks;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides block plugin definitions for iubenda blocks.
 */
final class IubendaBlockDeriver extends DeriverBase implements ContainerDeriverInterface {

  /**
   * Constructs the IubendaBlock deriver.
   *
   * @param \Drupal\Core\Config\ConfigFactory $configFactory
   *   The configuration factory service.
   */
  public function __construct(
    private readonly ConfigFactory $configFactory,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id): static {
    return new static(
      $container->get('config.factory'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition): array {
    foreach (IubendaBlocks::cases() as $case) {
      if (!$this->isConfigured($case)) {
        // Skip this block if the related configuration is not set.
        continue;
      }
      $this->derivatives[$case->name] = $base_plugin_definition;
      $this->derivatives[$case->name]['admin_label'] = "Iubenda: $case->value";
    }

    return $this->derivatives;
  }

  /**
   * Checks if the current deriver related configuration is set.
   *
   * @param \Drupal\iubenda_integration\Enum\IubendaBlocks $current_deriver
   *   The current deriver to check.
   *
   * @return bool
   *   TRUE if the deriver is configured, FALSE otherwise.
   */
  private function isConfigured(IubendaBlocks $current_deriver): bool {
    $config = $this->configFactory->get('iubenda_integration.settings');

    return match ($current_deriver->name) {
      IubendaBlocks::IubendaPrivacyPolicy->name,
      IubendaBlocks::IubendaCookiePolicy->name      => !empty($config->get('policy_url')),
      IubendaBlocks::IubendaTermsAndCondition->name => !empty($config->get('terms_and_condition_url')),
      default                                       => FALSE,
    };
  }

}
