<?php

declare(strict_types=1);

namespace Drupal\iubenda_integration\Traits;

/**
 * Provides a trait for iubenda settings.
 *
 * This trait defines the configuration name used for iubenda settings.
 *
 * @package Drupal\iubenda_integration\Traits
 */
trait IubendaSettingsTrait {

  protected const CONFIG_NAME = 'iubenda_integration.settings';

  /**
   * Extracts valid configuration keys from the schema definition.
   *
   * @return array
   *   An array of valid configuration keys that can be set by the user.
   */
  protected function extractValidConfigKeys(): array {
    // Get the schema definition for iubenda_integration.settings.
    $schema_definition = \Drupal::service('config.typed')->getDefinition(self::CONFIG_NAME);

    // Extract valid configuration keys from the schema.
    $valid_config_keys = [];
    if (isset($schema_definition['mapping'])) {
      $valid_config_keys = array_keys($schema_definition['mapping']);
      $valid_config_keys = array_filter($valid_config_keys, function ($key) {
        // Exclude keys that are not meant to be set by the user.
        return !in_array($key, ['_core', 'langcode']);
      });
    }

    return $valid_config_keys;
  }

}
