<?php

declare(strict_types=1);

namespace Drupal\Tests\iubenda_integration\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests administration of iubenda.
 *
 * @group iubenda_integration
 */
class IubendaAdminTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'iubenda_integration',
  ];

  /**
   * A user with the 'administer iubenda_integration' permission.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->adminUser = $this->drupalCreateUser(['administer iubenda_integration']);
  }

  /**
   * Tests the privacy policy page.
   */
  public function testPrivacyPolicy() {
    $this->drupalLogin($this->adminUser);
    $assert_session = $this->assertSession();
    $this->drupalGet('/admin/config/services/iubenda-integration');
    $assert_session->statusCodeEquals(200);
    $assert_session->pageTextContains('Privacy and Cookie Policy settings');
    $assert_session->responseContains('Privacy Policy URL');
  }

  /**
   * Tests the cookie solution page.
   */
  public function testCookieSolution() {
    $this->drupalLogin($this->adminUser);
    $assert_session = $this->assertSession();
    $this->drupalGet('/admin/config/services/iubenda-integration/cookie-policy');
    $assert_session->statusCodeEquals(200);
    $assert_session->pageTextContains('Privacy Controls and Cookie Solution settings');
    $assert_session->responseContains('Privacy Controls and Cookie Solution embed code');
  }

  /**
   * Tests the terms and condition page.
   */
  public function testTermsAndCondition() {
    $this->drupalLogin($this->adminUser);
    $assert_session = $this->assertSession();
    $this->drupalGet('/admin/config/services/iubenda-integration/terms-and-condition');
    $assert_session->statusCodeEquals(200);
    $assert_session->pageTextContains('Terms and Condition settings');
    $assert_session->responseContains('Term and Condition URL');
  }

  /**
   * Tests the cookie solution page.
   */
  public function testConsentDatabase() {
    $this->drupalLogin($this->adminUser);
    $assert_session = $this->assertSession();
    $this->drupalGet('/admin/config/services/iubenda-integration/consent-solution');
    $assert_session->statusCodeEquals(200);
    $assert_session->pageTextContains('Consent Database settings');
    $assert_session->responseContains('Api key');
  }

}
